package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.ASN1OutputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.misc.MiscObjectIdentifiers;
import cn.com.infosec.asn1.misc.NetscapeCertType;
import cn.com.infosec.asn1.misc.NetscapeRevocationURL;
import cn.com.infosec.asn1.misc.VerisignCzagExtension;
import cn.com.infosec.asn1.util.ASN1Dump;
import cn.com.infosec.asn1.util.SubjectDNUtil;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.BasicConstraints;
import cn.com.infosec.asn1.x509.KeyUsage;
import cn.com.infosec.asn1.x509.SubjectPublicKeyInfo;
import cn.com.infosec.asn1.x509.Time;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Extension;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import cn.com.infosec.jce.provider.fastparser.DerUtil;
import cn.com.infosec.jce.provider.fastparser.FX509Certificate;
import cn.com.infosec.util.Arrays;
import cn.com.infosec.util.encoders.Hex;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.Principal;
import java.security.Provider;
import java.security.PublicKey;
import java.security.Security;
import java.security.Signature;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import javax.security.auth.x500.X500Principal;

public class X509CertificateObjectFX extends X509Certificate implements PKCS12BagAttributeCarrier {
   private X509CertificateStructure c;
   private BasicConstraints basicConstraints;
   private boolean[] keyUsage;
   private PKCS12BagAttributeCarrier attrCarrier;
   byte[] certData;
   FX509Certificate fxCert;
   boolean isInvokeConstructMethod;
   int version;
   BigInteger serialNumber;
   Principal issuerDN;
   X500Principal issuerX500Principal;
   Principal subjectDN;
   X500Principal subjectX500Principal;
   Date notBefore;
   Date notAfter;
   byte[] tbsCertificate;
   byte[] signature;
   String sigAlgOID;
   AlgorithmIdentifier signatureAlgorithm;
   PublicKey publickey;
   byte[] encoded;
   AlgorithmIdentifier tbSCertificateSignature;

   public X509CertificateObjectFX(byte[] bs) {
      PKCS12BagAttributeCarrierImpl var2;
      var2 = new PKCS12BagAttributeCarrierImpl.<init>();
      this.attrCarrier = var2;
      this.certData = null;
      this.fxCert = null;
      this.isInvokeConstructMethod = false;
      this.version = -1;
      this.serialNumber = null;
      this.issuerDN = null;
      this.issuerX500Principal = null;
      this.subjectDN = null;
      this.subjectX500Principal = null;
      this.notBefore = null;
      this.notAfter = null;
      this.tbsCertificate = null;
      this.signature = null;
      this.sigAlgOID = null;
      this.signatureAlgorithm = null;
      this.publickey = null;
      this.encoded = null;
      this.tbSCertificateSignature = null;
      this.certData = bs;
      FX509Certificate bs1;
      FX509Certificate var10000 = bs1 = new FX509Certificate;
      bs1.<init>();
      this.fxCert = bs1;
      byte[] var3;
      int bs2 = (var3 = this.certData).length;
      var10000.parse(var3, 0, bs2);
   }

   private void invokeConstructMethod() {
      // $FF: Couldn't be decompiled
   }

   public X509CertificateObjectFX(X509CertificateStructure c) {
      X509CertificateObjectFX var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.certData = null;
      this.fxCert = null;
      this.isInvokeConstructMethod = false;
      this.version = -1;
      this.serialNumber = null;
      this.issuerDN = null;
      this.issuerX500Principal = null;
      this.subjectDN = null;
      this.subjectX500Principal = null;
      this.notBefore = null;
      this.notAfter = null;
      this.tbsCertificate = null;
      this.signature = null;
      this.sigAlgOID = null;
      this.signatureAlgorithm = null;
      this.publickey = null;
      this.encoded = null;
      this.tbSCertificateSignature = null;
      this.c = c;

      boolean var10001;
      Exception var19;
      byte[] c1;
      Exception var23;
      byte[] var24;
      label119: {
         label123: {
            try {
               var24 = var10000.getExtensionBytes("2.5.29.19");
            } catch (Exception var18) {
               var23 = var18;
               var10001 = false;
               break label123;
            }

            c1 = var24;
            if (var24 == null) {
               break label119;
            }

            try {
               this.basicConstraints = BasicConstraints.getInstance(ASN1Object.fromByteArray(c1));
               break label119;
            } catch (Exception var17) {
               var23 = var17;
               var10001 = false;
            }
         }

         var19 = var23;
         throw new CertificateParsingException("cannot construct BasicConstraints: " + var19);
      }

      label108: {
         try {
            var24 = this.getExtensionBytes("2.5.29.15");
         } catch (Exception var16) {
            var23 = var16;
            var10001 = false;
            break label108;
         }

         c1 = var24;
         if (var24 != null) {
            label124: {
               DERBitString var26;
               try {
                  var26 = DERBitString.getInstance(ASN1Object.fromByteArray(c1));
               } catch (Exception var14) {
                  var23 = var14;
                  var10001 = false;
                  break label124;
               }

               DERBitString c2 = var26;

               try {
                  var24 = var26.getBytes();
               } catch (Exception var13) {
                  var23 = var13;
                  var10001 = false;
                  break label124;
               }

               byte[] var2 = var24;

               int var28;
               try {
                  var28 = var24.length;
               } catch (Exception var12) {
                  var23 = var12;
                  var10001 = false;
                  break label124;
               }

               int var27;
               try {
                  var27 = c2.getPadBits();
               } catch (Exception var11) {
                  var23 = var11;
                  var10001 = false;
                  break label124;
               }

               int var3;
               int c3;
               if ((c3 = var28 * 8 - var27) < 9) {
                  var3 = 9;
               } else {
                  var3 = c3;
               }

               try {
                  this.keyUsage = new boolean[var3];
               } catch (Exception var10) {
                  var23 = var10;
                  var10001 = false;
                  break label124;
               }

               var3 = 0;

               while(true) {
                  if (var3 == c3) {
                     return;
                  }

                  boolean[] var10002;
                  try {
                     var24 = var2;
                     var27 = var3;
                     var10002 = this.keyUsage;
                  } catch (Exception var9) {
                     var23 = var9;
                     var10001 = false;
                     break;
                  }

                  boolean[] var4 = var10002;

                  byte var29;
                  try {
                     var29 = var24[var27 / 8];
                  } catch (Exception var8) {
                     var23 = var8;
                     var10001 = false;
                     break;
                  }

                  int var25;
                  try {
                     var25 = var3 % 8;
                  } catch (Exception var7) {
                     var23 = var7;
                     var10001 = false;
                     break;
                  }

                  boolean var5;
                  if ((var29 & 128 >>> var25) != 0) {
                     var5 = true;
                  } else {
                     var5 = false;
                  }

                  try {
                     var4[var3] = var5;
                  } catch (Exception var6) {
                     var23 = var6;
                     var10001 = false;
                     break;
                  }

                  ++var3;
               }
            }
         } else {
            try {
               this.keyUsage = null;
               return;
            } catch (Exception var15) {
               var23 = var15;
               var10001 = false;
            }
         }
      }

      var19 = var23;
      throw new CertificateParsingException("cannot construct KeyUsage: " + var19);
   }

   private byte[] getExtensionBytes(String oid) {
      byte[] var2 = null;
      FX509Certificate var3;
      X509Extensions var7;
      X509Extension var9;
      X509Extensions var10000;
      if ((var3 = this.fxCert) != null) {
         byte[] var10 = var3.getItemDataAndTag(var3.getExtensions());
         ASN1InputStream var12 = new ASN1InputStream(new ByteArrayInputStream(var10));

         byte[] var15;
         label42: {
            IOException var13;
            label50: {
               boolean var10001;
               try {
                  var10000 = X509Extensions.getInstance(var12.readObject());
               } catch (IOException var6) {
                  var13 = var6;
                  var10001 = false;
                  break label50;
               }

               var7 = var10000;
               if (var10000 == null) {
                  return var2;
               }

               X509Extension var14;
               try {
                  var14 = var7.getExtension(new DERObjectIdentifier(oid));
               } catch (IOException var5) {
                  var13 = var5;
                  var10001 = false;
                  break label50;
               }

               var9 = var14;
               if (var14 == null) {
                  return var2;
               }

               try {
                  var15 = var9.getValue().getOctets();
                  break label42;
               } catch (IOException var4) {
                  var13 = var4;
                  var10001 = false;
               }
            }

            IOException var11 = var13;
            throw new RuntimeException(var11.getMessage());
         }

         var2 = var15;
         return var2;
      } else {
         if ((var7 = this.getX509CertificateStructure().getTBSCertificate().getExtensions()) != null) {
            var10000 = var7;
            DERObjectIdentifier var8;
            var8 = new DERObjectIdentifier.<init>(oid);
            if ((var9 = var10000.getExtension(var8)) != null) {
               return var9.getValue().getOctets();
            }
         }

         return null;
      }
   }

   private void checkSignature(PublicKey key, Signature signature) {
      if (this.getX509CertificateStructure().getSignatureAlgorithm().equals(this.getX509CertificateStructure().getTBSCertificate().getSignature())) {
         if (this.getSignatureAlgorithm().equals(this.getTBSCertificateSignature())) {
            DEREncodable var3;
            if (this.fxCert != null) {
               var3 = this.getSignatureAlgorithm().getParameters();
            } else {
               var3 = this.getX509CertificateStructure().getSignatureAlgorithm().getParameters();
            }

            X509SignatureUtil.setSignatureParameters(signature, var3);
            signature.initVerify(key);
            signature.update(this.getTBSCertificate());
            if (!signature.verify(this.getSignature())) {
               throw new InvalidKeyException("Public key presented not for certificate signature");
            }
         } else {
            throw new CertificateException("signature algorithm in TBS cert not same as outer cert");
         }
      } else {
         throw new CertificateException("signature algorithm in TBS cert not same as outer cert");
      }
   }

   public X509CertificateStructure getX509CertificateStructure() {
      this.invokeConstructMethod();
      X509CertificateStructure var1;
      if ((var1 = this.c) != null) {
         return var1;
      } else {
         X509CertificateStructure var10000;
         boolean var10001;
         try {
            var10000 = X509CertificateStructure.getInstance((new ASN1InputStream(new ByteArrayInputStream(this.certData))).readObject());
         } catch (IOException var3) {
            var10001 = false;
            return null;
         }

         X509CertificateStructure var4 = var10000;

         try {
            this.c = var4;
            return var10000;
         } catch (IOException var2) {
            var10001 = false;
            return null;
         }
      }
   }

   public void checkValidity() {
      X509CertificateObjectFX var10000 = this;
      this.invokeConstructMethod();
      Date var1;
      var1 = new Date.<init>();
      var10000.checkValidity(var1);
   }

   public void checkValidity(Date date) {
      this.invokeConstructMethod();
      if (date.getTime() <= this.getNotAfter().getTime()) {
         if (date.getTime() < this.getNotBefore().getTime()) {
            throw new CertificateNotYetValidException("certificate not valid till " + this.getX509CertificateStructure().getStartDate().getTime());
         }
      } else {
         throw new CertificateExpiredException("certificate expired on " + this.getX509CertificateStructure().getEndDate().getTime());
      }
   }

   public int getVersion() {
      int var1;
      if ((var1 = this.version) != -1) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) == null) {
            return this.getX509CertificateStructure().getVersion();
         } else {
            byte[] var6;
            if ((var6 = var5.getItemData(var5.getVersion())).length == 0) {
               this.version = (new DERInteger(0)).getValue().intValue() + 1;
               return this.version;
            } else {
               IOException var10000;
               label38: {
                  boolean var10001;
                  X509CertificateObjectFX var7;
                  int var8;
                  try {
                     var7 = this;
                     var8 = DERInteger.getInstance((new ASN1InputStream(new ByteArrayInputStream(var6))).readObject()).getValue().intValue();
                  } catch (IOException var3) {
                     var10000 = var3;
                     var10001 = false;
                     break label38;
                  }

                  ++var8;

                  try {
                     var7.version = var8;
                     return this.version;
                  } catch (IOException var2) {
                     var10000 = var2;
                     var10001 = false;
                  }
               }

               IOException var4 = var10000;
               throw new RuntimeException(var4.getMessage());
            }
         }
      }
   }

   public BigInteger getSerialNumber() {
      BigInteger var1;
      if ((var1 = this.serialNumber) != null) {
         return var1;
      } else {
         FX509Certificate var2;
         if ((var2 = this.fxCert) != null) {
            byte[] var3 = var2.getItemData(var2.getSerialNumber());
            return this.serialNumber = new BigInteger(var3);
         } else {
            return this.getX509CertificateStructure().getSerialNumber().getValue();
         }
      }
   }

   public Principal getIssuerDN() {
      FX509Certificate var1;
      if ((var1 = this.fxCert) == null) {
         return new X509Principal(this.getX509CertificateStructure().getIssuer());
      } else {
         Principal var2;
         if ((var2 = this.issuerDN) != null) {
            return var2;
         } else {
            byte[] var7 = var1.getItemData(var1.getIssuer());

            Exception var10000;
            label41: {
               X509Name var9;
               boolean var10001;
               try {
                  var9 = X509Name.getInstance(SubjectDNUtil.sortDN(ASN1Sequence.getInstance((new ASN1InputStream(var7)).readObject()), "cn.com.infosec.jce.SortIssuerDN"));
               } catch (Exception var5) {
                  var10000 = var5;
                  var10001 = false;
                  break label41;
               }

               X509Name var8 = var9;

               X509Principal var10;
               try {
                  var10 = new X509Principal;
               } catch (Exception var4) {
                  var10000 = var4;
                  var10001 = false;
                  break label41;
               }

               X509Principal var11 = var10;

               try {
                  var11.<init>(var8);
                  this.issuerDN = var11;
                  return var10;
               } catch (Exception var3) {
                  var10000 = var3;
                  var10001 = false;
               }
            }

            Exception var6 = var10000;
            throw new RuntimeException(var6.getMessage());
         }
      }
   }

   public X500Principal getIssuerX500Principal() {
      X500Principal var1;
      if ((var1 = this.issuerX500Principal) != null) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) != null) {
            byte[] var7 = var5.getItemData(var5.getIssuer());
            return this.issuerX500Principal = new X500Principal(var7);
         } else {
            ByteArrayOutputStream var10000;
            boolean var10001;
            try {
               var10000 = new ByteArrayOutputStream;
            } catch (IOException var4) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }

            ByteArrayOutputStream var6 = var10000;

            ASN1OutputStream var8;
            try {
               var10000.<init>();
               var8 = new ASN1OutputStream;
            } catch (IOException var3) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }

            ASN1OutputStream var9 = var8;

            try {
               var9.<init>(var6);
               var8.writeObject(this.getX509CertificateStructure().getIssuer());
               return new X500Principal(var6.toByteArray());
            } catch (IOException var2) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }
         }
      }
   }

   public Principal getSubjectDN() {
      Principal var1;
      if ((var1 = this.subjectDN) != null) {
         return var1;
      } else {
         FX509Certificate var6;
         if ((var6 = this.fxCert) != null) {
            byte[] var7 = var6.getItemDataAndTag(var6.getSubject());

            Exception var10000;
            label42: {
               X509Name var9;
               boolean var10001;
               try {
                  var9 = X509Name.getInstance(SubjectDNUtil.sortDN(ASN1Sequence.getInstance((new ASN1InputStream(var7)).readObject()), "cn.com.infosec.jce.SortDN"));
               } catch (Exception var4) {
                  var10000 = var4;
                  var10001 = false;
                  break label42;
               }

               X509Name var8 = var9;

               X509Principal var10;
               try {
                  var10 = new X509Principal;
               } catch (Exception var3) {
                  var10000 = var3;
                  var10001 = false;
                  break label42;
               }

               X509Principal var11 = var10;

               try {
                  var11.<init>(var8);
                  this.subjectDN = var11;
                  return var10;
               } catch (Exception var2) {
                  var10000 = var2;
                  var10001 = false;
               }
            }

            Exception var5 = var10000;
            throw new RuntimeException(var5.getMessage());
         } else {
            return new X509Principal(this.getX509CertificateStructure().getSubject());
         }
      }
   }

   public X500Principal getSubjectX500Principal() {
      X500Principal var1;
      if ((var1 = this.subjectX500Principal) != null) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) != null) {
            byte[] var7 = var5.getItemDataAndTag(var5.getSubject());
            return this.subjectX500Principal = new X500Principal(var7);
         } else {
            ByteArrayOutputStream var10000;
            boolean var10001;
            try {
               var10000 = new ByteArrayOutputStream;
            } catch (IOException var4) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }

            ByteArrayOutputStream var6 = var10000;

            ASN1OutputStream var8;
            try {
               var10000.<init>();
               var8 = new ASN1OutputStream;
            } catch (IOException var3) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }

            ASN1OutputStream var9 = var8;

            try {
               var9.<init>(var6);
               var8.writeObject(this.getX509CertificateStructure().getSubject());
               return new X500Principal(var6.toByteArray());
            } catch (IOException var2) {
               var10001 = false;
               throw new IllegalStateException("can't encode issuer DN");
            }
         }
      }
   }

   public Date getNotBefore() {
      Date var1;
      if ((var1 = this.notBefore) != null) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) != null) {
            byte[] var6 = var5.getItemDataAndTag(var5.getValidity());
            ASN1InputStream var10000 = new ASN1InputStream(new ByteArrayInputStream(var6));

            IOException var7;
            label34: {
               boolean var10001;
               Date var8;
               try {
                  var8 = Time.getInstance(((ASN1Sequence)var10000.readObject()).getObjectAt(0)).getDate();
               } catch (IOException var3) {
                  var7 = var3;
                  var10001 = false;
                  break label34;
               }

               Date var9 = var8;

               try {
                  this.notBefore = var9;
                  return var8;
               } catch (IOException var2) {
                  var7 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var7;
            throw new RuntimeException(var4.getMessage());
         } else {
            return this.getX509CertificateStructure().getStartDate().getDate();
         }
      }
   }

   public Date getNotAfter() {
      Date var1;
      if ((var1 = this.notAfter) != null) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) != null) {
            byte[] var6 = var5.getItemDataAndTag(var5.getValidity());
            ASN1InputStream var10000 = new ASN1InputStream(new ByteArrayInputStream(var6));

            IOException var7;
            label34: {
               boolean var10001;
               Date var8;
               try {
                  var8 = Time.getInstance(((ASN1Sequence)var10000.readObject()).getObjectAt(1)).getDate();
               } catch (IOException var3) {
                  var7 = var3;
                  var10001 = false;
                  break label34;
               }

               Date var9 = var8;

               try {
                  this.notAfter = var9;
                  return var8;
               } catch (IOException var2) {
                  var7 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var7;
            throw new RuntimeException(var4.getMessage());
         } else {
            return this.getX509CertificateStructure().getEndDate().getDate();
         }
      }
   }

   public byte[] getTBSCertificate() {
      byte[] var1;
      if ((var1 = this.tbsCertificate) != null) {
         return var1;
      } else {
         FX509Certificate var3;
         if ((var3 = this.fxCert) != null) {
            return this.tbsCertificate = var3.getItemDataAndTag(var3.getTbsCertificate());
         } else {
            ByteArrayOutputStream var4;
            ByteArrayOutputStream var10000 = var4 = new ByteArrayOutputStream;
            var10000.<init>();
            X509CertificateObjectFX var10002 = this;
            DEROutputStream var10001 = new DEROutputStream(var4);

            try {
               var10001.writeObject(var10002.getX509CertificateStructure().getTBSCertificate());
               return var10000.toByteArray();
            } catch (IOException var2) {
               throw new CertificateEncodingException(var2.toString());
            }
         }
      }
   }

   public byte[] getSignature() {
      byte[] var1;
      if ((var1 = this.signature) != null) {
         return var1;
      } else {
         FX509Certificate var4;
         if ((var4 = this.fxCert) != null) {
            byte[] var2;
            byte[] var10000 = var2 = new byte[(var1 = var4.getItemData(var4.getSignatureValue())).length - 1];
            X509CertificateObjectFX var10001 = this;
            int var3 = var1.length - 1;
            System.arraycopy(var1, 1, var2, 0, var3);
            var10001.signature = var2;
            return var10000;
         } else {
            return this.getX509CertificateStructure().getSignature().getBytes();
         }
      }
   }

   public String getSigAlgName() {
      this.invokeConstructMethod();
      Provider var1;
      String var4;
      if ((var1 = Security.getProvider("INFOSEC")) != null && (var4 = var1.getProperty("Alg.Alias.Signature." + this.getSigAlgOID())) != null) {
         return var4;
      } else {
         Provider[] var5 = Security.getProviders();

         for(int var2 = 0; var2 != var5.length; ++var2) {
            String var3;
            if ((var3 = var5[var2].getProperty("Alg.Alias.Signature." + this.getSigAlgOID())) != null) {
               return var3;
            }
         }

         return this.getSigAlgOID();
      }
   }

   public String getSigAlgOID() {
      String var1;
      if ((var1 = this.sigAlgOID) != null) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) != null) {
            byte[] var10000 = var5.getItemData(var5.getSignatureAlgorithm());

            IOException var6;
            label34: {
               boolean var10001;
               String var7;
               try {
                  var7 = AlgorithmIdentifier.getInstance(DerUtil.getDerObject(var10000)).getObjectId().getId();
               } catch (IOException var3) {
                  var6 = var3;
                  var10001 = false;
                  break label34;
               }

               String var8 = var7;

               try {
                  this.sigAlgOID = var8;
                  return var7;
               } catch (IOException var2) {
                  var6 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var6;
            throw new RuntimeException(var4.getMessage());
         } else {
            return this.getX509CertificateStructure().getSignatureAlgorithm().getObjectId().getId();
         }
      }
   }

   public AlgorithmIdentifier getSignatureAlgorithm() {
      AlgorithmIdentifier var1;
      if ((var1 = this.signatureAlgorithm) != null) {
         return var1;
      } else {
         FX509Certificate var3;
         if ((var3 = this.fxCert) != null) {
            X509CertificateObjectFX var10000 = this;
            byte[] var10001 = var3.getItemData(var3.getSignatureAlgorithm());

            try {
               var10000.signatureAlgorithm = AlgorithmIdentifier.getInstance(DerUtil.getDerObject(var10001));
            } catch (IOException var2) {
               throw new RuntimeException(var2.getMessage());
            }
         }

         return this.signatureAlgorithm;
      }
   }

   public byte[] getSigAlgParams() {
      this.invokeConstructMethod();
      return this.getX509CertificateStructure().getSignatureAlgorithm().getParameters() != null ? this.getX509CertificateStructure().getSignatureAlgorithm().getParameters().getDERObject().getDEREncoded() : null;
   }

   public boolean[] getIssuerUniqueID() {
      this.invokeConstructMethod();
      DERBitString var5;
      if ((var5 = this.getX509CertificateStructure().getTBSCertificate().getIssuerUniqueId()) != null) {
         byte[] var1;
         int var6;
         boolean[] var2 = new boolean[var6 = (var1 = var5.getBytes()).length * 8 - var5.getPadBits()];

         for(int var3 = 0; var3 != var6; ++var3) {
            boolean var4;
            if ((var1[var3 / 8] & 128 >>> var3 % 8) != 0) {
               var4 = true;
            } else {
               var4 = false;
            }

            var2[var3] = var4;
         }

         return var2;
      } else {
         return null;
      }
   }

   public boolean[] getSubjectUniqueID() {
      this.invokeConstructMethod();
      DERBitString var5;
      if ((var5 = this.getX509CertificateStructure().getTBSCertificate().getSubjectUniqueId()) != null) {
         byte[] var1;
         int var6;
         boolean[] var2 = new boolean[var6 = (var1 = var5.getBytes()).length * 8 - var5.getPadBits()];

         for(int var3 = 0; var3 != var6; ++var3) {
            boolean var4;
            if ((var1[var3 / 8] & 128 >>> var3 % 8) != 0) {
               var4 = true;
            } else {
               var4 = false;
            }

            var2[var3] = var4;
         }

         return var2;
      } else {
         return null;
      }
   }

   public boolean[] getKeyUsage() {
      this.invokeConstructMethod();
      return this.keyUsage;
   }

   public List getExtendedKeyUsage() {
      this.invokeConstructMethod();
      byte[] var9;
      if ((var9 = this.getExtensionBytes("2.5.29.37")) != null) {
         ASN1Sequence var10000;
         boolean var10001;
         try {
            var10000 = (ASN1Sequence)(new ASN1InputStream(var9)).readObject();
         } catch (Exception var8) {
            var10001 = false;
            throw new CertificateParsingException("error processing extended key usage extension");
         }

         ASN1Sequence var10 = var10000;

         ArrayList var11;
         try {
            var11 = new ArrayList;
         } catch (Exception var7) {
            var10001 = false;
            throw new CertificateParsingException("error processing extended key usage extension");
         }

         ArrayList var1 = var11;

         try {
            var11.<init>();
         } catch (Exception var6) {
            var10001 = false;
            throw new CertificateParsingException("error processing extended key usage extension");
         }

         int var2 = 0;

         while(true) {
            int var12;
            int var13;
            try {
               var12 = var2;
               var13 = var10.size();
            } catch (Exception var4) {
               var10001 = false;
               break;
            }

            if (var12 == var13) {
               try {
                  return Collections.unmodifiableList(var1);
               } catch (Exception var3) {
                  var10001 = false;
                  break;
               }
            }

            try {
               var1.add(((DERObjectIdentifier)var10.getObjectAt(var2)).getId());
            } catch (Exception var5) {
               var10001 = false;
               break;
            }

            ++var2;
         }

         throw new CertificateParsingException("error processing extended key usage extension");
      } else {
         return null;
      }
   }

   public int getBasicConstraints() {
      byte[] var1;
      if (this.basicConstraints == null && (var1 = this.getExtensionBytes("2.5.29.19")) != null) {
         try {
            this.basicConstraints = BasicConstraints.getInstance(DerUtil.getDerObject(var1));
         } catch (IOException var2) {
            return -1;
         }
      }

      BasicConstraints var3;
      if ((var3 = this.basicConstraints) != null) {
         if (var3.isCA()) {
            return this.basicConstraints.getPathLenConstraint() == null ? Integer.MAX_VALUE : this.basicConstraints.getPathLenConstraint().intValue();
         } else {
            return -1;
         }
      } else {
         return -1;
      }
   }

   public Set getCriticalExtensionOIDs() {
      this.invokeConstructMethod();
      if (this.getVersion() == 3) {
         X509CertificateObjectFX var10000 = this;
         HashSet var4;
         var4 = new HashSet.<init>();
         X509Extensions var1;
         if ((var1 = var10000.getX509CertificateStructure().getTBSCertificate().getExtensions()) != null) {
            Enumeration var2 = var1.oids();

            while(var2.hasMoreElements()) {
               DERObjectIdentifier var3;
               if (var1.getExtension(var3 = (DERObjectIdentifier)var2.nextElement()).isCritical()) {
                  var4.add(var3.getId());
               }
            }

            return var4;
         }
      }

      return null;
   }

   public byte[] getExtensionValue(String oid) {
      byte[] var2 = null;
      FX509Certificate var3;
      X509Extensions var8;
      X509Extension var10;
      X509Extensions var10000;
      if ((var3 = this.fxCert) != null) {
         byte[] var11 = var3.getItemDataAndTag(var3.getExtensions());
         ASN1InputStream var13 = new ASN1InputStream(new ByteArrayInputStream(var11));

         byte[] var16;
         label46: {
            IOException var14;
            label54: {
               boolean var10001;
               try {
                  var10000 = X509Extensions.getInstance(var13.readObject());
               } catch (IOException var7) {
                  var14 = var7;
                  var10001 = false;
                  break label54;
               }

               var8 = var10000;
               if (var10000 == null) {
                  return var2;
               }

               X509Extension var15;
               try {
                  var15 = var8.getExtension(new DERObjectIdentifier(oid));
               } catch (IOException var6) {
                  var14 = var6;
                  var10001 = false;
                  break label54;
               }

               var10 = var15;
               if (var15 == null) {
                  return var2;
               }

               try {
                  var16 = var10.getValue().getEncoded();
                  break label46;
               } catch (IOException var5) {
                  var14 = var5;
                  var10001 = false;
               }
            }

            IOException var12 = var14;
            throw new RuntimeException(var12.getMessage());
         }

         var2 = var16;
         return var2;
      } else {
         if ((var8 = this.getX509CertificateStructure().getTBSCertificate().getExtensions()) != null) {
            var10000 = var8;
            DERObjectIdentifier var9;
            var9 = new DERObjectIdentifier.<init>(oid);
            if ((var10 = var10000.getExtension(var9)) != null) {
               try {
                  return var10.getValue().getEncoded();
               } catch (Exception var4) {
                  throw new IllegalStateException("error parsing " + var4.toString());
               }
            }
         }

         return null;
      }
   }

   public Set getNonCriticalExtensionOIDs() {
      this.invokeConstructMethod();
      if (this.getVersion() == 3) {
         X509CertificateObjectFX var10000 = this;
         HashSet var4;
         var4 = new HashSet.<init>();
         X509Extensions var1;
         if ((var1 = var10000.getX509CertificateStructure().getTBSCertificate().getExtensions()) != null) {
            Enumeration var2 = var1.oids();

            while(var2.hasMoreElements()) {
               DERObjectIdentifier var3;
               if (!var1.getExtension(var3 = (DERObjectIdentifier)var2.nextElement()).isCritical()) {
                  var4.add(var3.getId());
               }
            }

            return var4;
         }
      }

      return null;
   }

   public boolean hasUnsupportedCriticalExtension() {
      this.invokeConstructMethod();
      X509Extensions var4;
      if (this.getVersion() == 3 && (var4 = this.getX509CertificateStructure().getTBSCertificate().getExtensions()) != null) {
         Enumeration var1 = var4.oids();

         while(var1.hasMoreElements()) {
            DERObjectIdentifier var2;
            String var3;
            if (!(var3 = (var2 = (DERObjectIdentifier)var1.nextElement()).getId()).equals(RFC3280CertPathUtilities.KEY_USAGE) && !var3.equals(RFC3280CertPathUtilities.CERTIFICATE_POLICIES) && !var3.equals(RFC3280CertPathUtilities.POLICY_MAPPINGS) && !var3.equals(RFC3280CertPathUtilities.INHIBIT_ANY_POLICY) && !var3.equals(RFC3280CertPathUtilities.CRL_DISTRIBUTION_POINTS) && !var3.equals(RFC3280CertPathUtilities.ISSUING_DISTRIBUTION_POINT) && !var3.equals(RFC3280CertPathUtilities.DELTA_CRL_INDICATOR) && !var3.equals(RFC3280CertPathUtilities.POLICY_CONSTRAINTS) && !var3.equals(RFC3280CertPathUtilities.BASIC_CONSTRAINTS) && !var3.equals(RFC3280CertPathUtilities.SUBJECT_ALTERNATIVE_NAME) && !var3.equals(RFC3280CertPathUtilities.NAME_CONSTRAINTS) && var4.getExtension(var2).isCritical()) {
               return true;
            }
         }
      }

      return false;
   }

   public PublicKey getPublicKey() {
      PublicKey var1;
      if ((var1 = this.publickey) != null) {
         return var1;
      } else {
         FX509Certificate var5;
         if ((var5 = this.fxCert) != null) {
            byte[] var6 = var5.getItemDataAndTag(var5.getSubjectPublicKeyInfo());
            ASN1InputStream var10000 = new ASN1InputStream(new ByteArrayInputStream(var6));

            IOException var7;
            label34: {
               boolean var10001;
               PublicKey var8;
               try {
                  var8 = JDKKeyFactory.createPublicKeyFromPublicKeyInfo(SubjectPublicKeyInfo.getInstance(var10000.readObject()));
               } catch (IOException var3) {
                  var7 = var3;
                  var10001 = false;
                  break label34;
               }

               PublicKey var9 = var8;

               try {
                  this.publickey = var9;
                  return var8;
               } catch (IOException var2) {
                  var7 = var2;
                  var10001 = false;
               }
            }

            IOException var4 = var7;
            throw new RuntimeException(var4.getMessage());
         } else {
            return JDKKeyFactory.createPublicKeyFromPublicKeyInfo(this.getX509CertificateStructure().getSubjectPublicKeyInfo());
         }
      }
   }

   public byte[] getEncoded() {
      byte[] var1;
      if ((var1 = this.encoded) != null) {
         return var1;
      } else if (this.fxCert != null) {
         return this.encoded = this.certData;
      } else {
         ByteArrayOutputStream var3;
         ByteArrayOutputStream var10000 = var3 = new ByteArrayOutputStream;
         var10000.<init>();
         X509CertificateObjectFX var10002 = this;
         DEROutputStream var10001 = new DEROutputStream(var3);

         try {
            var10001.writeObject(var10002.c);
            return var10000.toByteArray();
         } catch (IOException var2) {
            throw new CertificateEncodingException(var2.toString());
         }
      }
   }

   public boolean equals(Object o) {
      this.invokeConstructMethod();
      if (o == this) {
         return true;
      } else if (!(o instanceof Certificate)) {
         return false;
      } else {
         X509CertificateObjectFX var10000 = this;
         Certificate var3 = (Certificate)o;

         try {
            return Arrays.areEqual(var10000.getEncoded(), var3.getEncoded());
         } catch (CertificateEncodingException var2) {
            return false;
         }
      }
   }

   public int hashCode() {
      X509CertificateObjectFX var10000 = this;
      this.invokeConstructMethod();

      boolean var10001;
      byte[] var8;
      try {
         var8 = var10000.getEncoded();
      } catch (CertificateEncodingException var6) {
         var10001 = false;
         return 0;
      }

      byte[] var7 = var8;
      int var1 = 0;
      int var2 = 0;

      while(true) {
         int var9;
         int var10;
         try {
            var9 = var2;
            var10 = var7.length;
         } catch (CertificateEncodingException var5) {
            var10001 = false;
            break;
         }

         if (var9 == var10) {
            return var1;
         }

         byte var11;
         try {
            var9 = var1;
            var11 = var7[var2];
         } catch (CertificateEncodingException var4) {
            var10001 = false;
            break;
         }

         int var10002;
         try {
            var10002 = var2 % 4;
         } catch (CertificateEncodingException var3) {
            var10001 = false;
            break;
         }

         var1 = var9 ^ (var11 & 255) << var10002;
         ++var2;
      }

      return 0;
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.invokeConstructMethod();
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      this.invokeConstructMethod();
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      this.invokeConstructMethod();
      return this.attrCarrier.getBagAttributeKeys();
   }

   public String toString() {
      this.invokeConstructMethod();
      StringBuffer var1;
      StringBuffer var10000 = var1 = new StringBuffer;
      var1.<init>();
      String var2 = System.getProperty("line.separator");
      var1.append("  [0]         Version: ").append(this.getVersion()).append(var2);
      var1.append("         SerialNumber: ").append(this.getSerialNumber()).append(var2);
      var1.append("             IssuerDN: ").append(this.getIssuerDN()).append(var2);
      var1.append("           Start Date: ").append(this.getNotBefore()).append(var2);
      var1.append("           Final Date: ").append(this.getNotAfter()).append(var2);
      var1.append("            SubjectDN: ").append(this.getSubjectDN()).append(var2);
      var1.append("           Public Key: ").append(this.getPublicKey()).append(var2);
      var1.append("  Signature Algorithm: ").append(this.getSigAlgName()).append(var2);
      byte[] var3 = this.getSignature();
      var10000.append("            Signature: ").append(new String(Hex.encode(var3, 0, 20))).append(var2);

      for(int var4 = 20; var4 < var3.length; var4 += 20) {
         if (var4 < var3.length - 20) {
            var1.append("                       ").append(new String(Hex.encode(var3, var4, 20))).append(var2);
         } else {
            var1.append("                       ").append(new String(Hex.encode(var3, var4, var3.length - var4))).append(var2);
         }
      }

      X509Extensions var20;
      if ((var20 = this.getX509CertificateStructure().getTBSCertificate().getExtensions()) != null) {
         Enumeration var21;
         if ((var21 = var20.oids()).hasMoreElements()) {
            var1.append("       Extensions: \n");
         }

         while(true) {
            while(true) {
               while(var21.hasMoreElements()) {
                  X509Extension var5;
                  DERObjectIdentifier var22;
                  if ((var5 = var20.getExtension(var22 = (DERObjectIdentifier)var21.nextElement())).getValue() != null) {
                     DERObjectIdentifier var23 = var22;
                     byte[] var6 = var5.getValue().getOctets();
                     ASN1InputStream var7;
                     var7 = new ASN1InputStream.<init>(var6);
                     var1.append("                       critical(").append(var5.isCritical()).append(") ");

                     label108: {
                        boolean var10001;
                        boolean var24;
                        try {
                           var24 = var23.equals(X509Extensions.BasicConstraints);
                        } catch (Exception var19) {
                           var10001 = false;
                           break label108;
                        }

                        if (var24) {
                           try {
                              var1.append(new BasicConstraints((ASN1Sequence)var7.readObject())).append(var2);
                              continue;
                           } catch (Exception var8) {
                              var10001 = false;
                           }
                        } else {
                           label104: {
                              try {
                                 var24 = var22.equals(X509Extensions.KeyUsage);
                              } catch (Exception var18) {
                                 var10001 = false;
                                 break label104;
                              }

                              if (var24) {
                                 try {
                                    var1.append(new KeyUsage((DERBitString)var7.readObject())).append(var2);
                                    continue;
                                 } catch (Exception var9) {
                                    var10001 = false;
                                 }
                              } else {
                                 label100: {
                                    try {
                                       var24 = var22.equals(MiscObjectIdentifiers.netscapeCertType);
                                    } catch (Exception var17) {
                                       var10001 = false;
                                       break label100;
                                    }

                                    if (var24) {
                                       try {
                                          var1.append(new NetscapeCertType((DERBitString)var7.readObject())).append(var2);
                                          continue;
                                       } catch (Exception var10) {
                                          var10001 = false;
                                       }
                                    } else {
                                       label96: {
                                          try {
                                             var24 = var22.equals(MiscObjectIdentifiers.netscapeRevocationURL);
                                          } catch (Exception var16) {
                                             var10001 = false;
                                             break label96;
                                          }

                                          if (var24) {
                                             try {
                                                var1.append(new NetscapeRevocationURL((DERIA5String)var7.readObject())).append(var2);
                                                continue;
                                             } catch (Exception var11) {
                                                var10001 = false;
                                             }
                                          } else {
                                             label92: {
                                                try {
                                                   var24 = var22.equals(MiscObjectIdentifiers.verisignCzagExtension);
                                                } catch (Exception var15) {
                                                   var10001 = false;
                                                   break label92;
                                                }

                                                if (var24) {
                                                   try {
                                                      var1.append(new VerisignCzagExtension((DERIA5String)var7.readObject())).append(var2);
                                                      continue;
                                                   } catch (Exception var12) {
                                                      var10001 = false;
                                                   }
                                                } else {
                                                   label127: {
                                                      try {
                                                         var10000 = var1;
                                                         var1.append(var22.getId());
                                                      } catch (Exception var14) {
                                                         var10001 = false;
                                                         break label127;
                                                      }

                                                      try {
                                                         var10000.append(" value = ").append(ASN1Dump.dumpAsString(var7.readObject())).append(var2);
                                                         continue;
                                                      } catch (Exception var13) {
                                                         var10001 = false;
                                                      }
                                                   }
                                                }
                                             }
                                          }
                                       }
                                    }
                                 }
                              }
                           }
                        }
                     }

                     var1.append(var22.getId());
                     var1.append(" value = ").append("*****").append(var2);
                  } else {
                     var1.append(var2);
                  }
               }

               return var1.toString();
            }
         }
      } else {
         return var1.toString();
      }
   }

   public final void verify(PublicKey key) {
      String var2;
      if (this.fxCert != null) {
         var2 = X509SignatureUtil.getSignatureName(this.getSignatureAlgorithm());
      } else {
         var2 = X509SignatureUtil.getSignatureName(this.getX509CertificateStructure().getSignatureAlgorithm());
      }

      Signature var4;
      label16: {
         Signature var10000;
         try {
            var10000 = Signature.getInstance(var2, "INFOSEC");
         } catch (Exception var3) {
            var4 = Signature.getInstance(var2);
            break label16;
         }

         var4 = var10000;
      }

      this.checkSignature(key, var4);
   }

   public final void verify(PublicKey key, String sigProvider) {
      Signature sigProvider1 = Signature.getInstance(this.fxCert != null ? X509SignatureUtil.getSignatureName(this.getSignatureAlgorithm()) : X509SignatureUtil.getSignatureName(this.getX509CertificateStructure().getSignatureAlgorithm()), sigProvider);
      this.checkSignature(key, sigProvider1);
   }

   AlgorithmIdentifier getTBSCertificateSignature() {
      AlgorithmIdentifier var1;
      if ((var1 = this.tbSCertificateSignature) != null) {
         return var1;
      } else {
         FX509Certificate var2;
         if ((var2 = this.fxCert) != null) {
            byte[] var10000 = var2.getItemData(var2.getSignature());

            IOException var6;
            label34: {
               boolean var10001;
               AlgorithmIdentifier var7;
               try {
                  var7 = AlgorithmIdentifier.getInstance(DerUtil.getDerObject(var10000));
               } catch (IOException var4) {
                  var6 = var4;
                  var10001 = false;
                  break label34;
               }

               AlgorithmIdentifier var8 = var7;

               try {
                  this.tbSCertificateSignature = var8;
                  return var7;
               } catch (IOException var3) {
                  var6 = var3;
                  var10001 = false;
               }
            }

            IOException var5 = var6;
            throw new RuntimeException(var5.getMessage());
         } else {
            return var1;
         }
      }
   }
}
